pub enum Color {
Black,
Red,
Green,
Yellow,
Blue,
Purple,
Cyan,
White,
Fixed(u8),
RGB(u8, u8, u8),
}Expand description
Color for styling. A colour is one specific type of ANSI escape code, and can refer to either the foreground or background colour.
These use the standard numeric sequences. See http://invisible-island.net/xterm/ctlseqs/ctlseqs.html
Variants
Black
Colour #0 (foreground code 30, background code 40).
This is not necessarily the background colour, and using it as one may render the text hard to read on terminals with dark backgrounds.
Red
Colour #1 (foreground code 31, background code 41).
Green
Colour #2 (foreground code 32, background code 42).
Yellow
Colour #3 (foreground code 33, background code 43).
Blue
Colour #4 (foreground code 34, background code 44).
Purple
Colour #5 (foreground code 35, background code 45).
Cyan
Colour #6 (foreground code 36, background code 46).
White
Colour #7 (foreground code 37, background code 47).
As above, this is not necessarily the foreground colour, and may be hard to read on terminals with light backgrounds.
Fixed(u8)
A colour number from 0 to 255, for use in 256-colour terminal environments.
- Colours 0 to 7 are the
BlacktoWhitevariants respectively. These colours can usually be changed in the terminal emulator. - Colours 8 to 15 are brighter versions of the eight colours above. These can also usually be changed in the terminal emulator, or it could be configured to use the original colours and show the text in bold instead. It varies depending on the program.
- Colours 16 to 231 contain several palettes of bright colours, arranged in six squares measuring six by six each.
- Colours 232 to 255 are shades of grey from black to white.
It might make more sense to look at a [colour chart][cc]. [cc]: https://upload.wikimedia.org/wikipedia/en/1/15/Xterm_256color_chart.svg
RGB(u8, u8, u8)
A 24-bit RGB color, as specified by ISO-8613-3.
Implementations
Sourceimpl Colour
impl Colour
Sourcepub fn paint<'a, S>(self, input: S) -> ANSIString<'a>
pub fn paint<'a, S>(self, input: S) -> ANSIString<'a>
Paints the given text with this colour, returning an ANSI string. This is a short-cut so you don’t have to use Blue.normal() just to get blue text.
Returns a Style with the hidden property set.
Sourcepub fn strikethrough(self) -> Style
pub fn strikethrough(self) -> Style
Returns a Style with the strikethrough property set.